({
    // "title": "三菱PLC-MC",
    // "title": "OPC-UA 驱动",
    // "key": "opcua",
    // "key": "mitsubishi-mc",
    "driver": {
        "properties": {
            "settings": {
                "title": "实例配置",
                "type": "object",
                "properties": {
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "clsid",
                        "description": "为空时根据progId获取，不为空时使用指定的clsid"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": ["host", "domain", "user", "password", "progid"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    },
    "model": {
        "properties": {
            "settings": {
                "title": "模型配置",
                "type": "object",
                "properties": {
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "clsid",
                        "description": "为空时根据progId获取，不为空时使用指定的clsid"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": ["host", "domain", "user", "password", "progid"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    },
    "device": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "clsid",
                        "description": "为空时根据progId获取，不为空时使用指定的clsid"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "overWrite": {
                        "type": "boolean",
                        "title": "不继承模型的数据点",
                        "description": "默认情况下资产数据点为其自身的和模型的数据点的合集"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": ["host", "domain", "user", "password", "progid"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    }
})
